@@ -85,10 +85,9 @@ mod build_bundled {
     pub fn main(out_dir: &str, out_path: &Path) {
         let lib_name = super::lib_name();
 
-        if cfg!(feature = "bundled-windows") && !cfg!(feature = "bundled") && !win_target() {
-            // This is just a sanity check, the top level `main` should ensure this.
-            panic!("This module should not be used: we're not on Windows and the bundled feature has not been enabled");
-        }
+        // This is just a sanity check, the top level `main` should ensure this.
+        assert!(!(cfg!(feature = "bundled-windows") && !cfg!(feature = "bundled") && !win_target()),
+            "This module should not be used: we're not on Windows and the bundled feature has not been enabled");
 
         #[cfg(feature = "buildtime_bindgen")]
         {
@@ -159,12 +158,11 @@ mod build_bundled {
                         let lib_dir = lib_dir.unwrap_or_else(|| openssl_dir.join("lib"));
                         let inc_dir = inc_dir.unwrap_or_else(|| openssl_dir.join("include"));
 
-                        if !Path::new(&lib_dir).exists() {
-                            panic!(
-                                "OpenSSL library directory does not exist: {}",
-                                lib_dir.to_string_lossy()
-                            );
-                        }
+                        assert!(
+                            Path::new(&lib_dir).exists(),
+                            "OpenSSL library directory does not exist: {}",
+                            lib_dir.to_string_lossy()
+                        );
 
                         if !Path::new(&inc_dir).exists() {
                             panic!(
@@ -181,9 +179,11 @@ mod build_bundled {
 
             if cfg!(feature = "bundled-sqlcipher-vendored-openssl") {
                 cfg.include(std::env::var("DEP_OPENSSL_INCLUDE").unwrap());
-                // cargo will resolve downstream to the static lib in openssl-sys
+                // cargo will resolve downstream to the static lib in
+                // openssl-sys
             } else if is_windows {
-                // Windows without `-vendored-openssl` takes this to link against a prebuilt OpenSSL lib
+                // Windows without `-vendored-openssl` takes this to link against a prebuilt
+                // OpenSSL lib
                 cfg.include(inc_dir.to_string_lossy().as_ref());
                 let lib = lib_dir.join("libcrypto.lib");
                 cfg.flag(lib.to_string_lossy().as_ref());
@@ -194,7 +194,7 @@ mod build_bundled {
                 println!("cargo:rustc-link-search={}", lib_dir.to_string_lossy());
             } else if is_apple {
                 cfg.flag("-DSQLCIPHER_CRYPTO_CC");
-                println!("cargo:rustc-link-lib=framework=SecurityFoundation");
+                println!("cargo:rustc-link-lib=framework=Security");
                 println!("cargo:rustc-link-lib=framework=CoreFoundation");
             } else {
                 // branch not taken on Windows, just `crypto` is fine.
@@ -213,7 +213,8 @@ mod build_bundled {
             cfg.flag("-fsanitize=address");
         }
 
-        // If explicitly requested: enable static linking against the Microsoft Visual C++ Runtime to avoid dependencies on vcruntime140.dll and similar libraries.
+        // If explicitly requested: enable static linking against the Microsoft Visual
+        // C++ Runtime to avoid dependencies on vcruntime140.dll and similar libraries.
         if cfg!(target_feature = "crt-static") && is_compiler("msvc") {
             cfg.static_crt(true);
         }
